@@ -61,13 +61,14 @@ class DaemonService(rpyc.Service):
 
     def exposed_handle_cli(self, args):
         args = rpyc.utils.classic.obtain(args)
+        log.debug('Running command `%s` for client.' % ' '.join(args))
         parser = get_parser()
         try:
-            options = parser.parse_args(args, raise_errors=True)
-        except ParserError as e:
-            # Recreate the normal error text to the client's console
-            self.client_console('error: ' + e.message)
-            e.parser.print_help(self.client_out_stream)
+            options = parser.parse_args(args, file=self.client_out_stream)
+        except SystemExit as e:
+            if e.code:
+                # TODO: Not sure how to properly propagate the exit code back to client
+                log.debug('Parsing cli args caused system exit with status %s.' % e.code)
             return
         if not options.cron:
             with capture_output(self.client_out_stream, loglevel=options.loglevel):
